import enum

from armarx_memory.ice_conv.ice_converter import IceConverter
from armarx_skills.core import dto


class ExecutionStatus(enum.Enum):
    Constructing = enum.auto()
    Initializing = enum.auto()
    Preparing = enum.auto()

    Running = enum.auto()
    Failed = enum.auto()
    Succeeded = enum.auto()
    Aborted = enum.auto()

    def is_succeeded(self) -> bool:
        return self == self.Succeeded


class ExecutionStatusConv(IceConverter):

    def __init__(self):
        super().__init__()
        self.py_to_ice_map = {
            ExecutionStatus.Constructing: dto.Status.Constructing,
            ExecutionStatus.Initializing: dto.Status.Initializing,
            ExecutionStatus.Preparing: dto.Status.Preparing,
            ExecutionStatus.Running: dto.Status.Running,
            ExecutionStatus.Failed: dto.Status.Failed,
            ExecutionStatus.Succeeded: dto.Status.Succeeded,
            ExecutionStatus.Aborted: dto.Status.Aborted,
        }
        self.ice_to_py_map = {i: p for p, i in self.py_to_ice_map.items()}

    @classmethod
    def _import_dto(cls):
        return dto.Status

    def _from_ice(self, dt: dto.Status) -> ExecutionStatus:
        return self.ice_to_py_map[dt]

    def _to_ice(self, bo: ExecutionStatus) -> dto.Status:
        return self.py_to_ice_map[bo]
