import dataclasses as dc

from armarx_skills.manager import dto
from armarx_skills.manager.skill_id import ProviderID, ProviderIDConv
from armarx_skills.manager.skill_description import SkillDescriptionMap, SkillDescriptionMapConv
from armarx_skills.provider import dti as provider_dti

from armarx_memory.ice_conv.ice_converter import IceConverter


@dc.dataclass
class ProviderInfo:
    provider_id: ProviderID
    provider_interface: provider_dti.SkillProviderInterfacePrx
    provided_skills: SkillDescriptionMap


class ProviderInfoConv(IceConverter):

    def __init__(self):
        super().__init__()
        self.provider_id_conv = ProviderIDConv()
        self.skillDescriptionMapConv = SkillDescriptionMapConv()

    @classmethod
    def _import_dto(cls):
        return dto.ProviderInfo

    def _from_ice(self, dt: dto.ProviderInfo) -> ProviderInfo:
        return ProviderInfo(
            provider_id=self.provider_id_conv.from_ice(dt.providerId),
            provider_interface=dt.providerInterface,
            provided_skills=self.skillDescriptionMapConv.from_ice(dt.providedSkills),
        )

    def _to_ice(self, bo: ProviderInfo) -> dto.ProviderInfo:
        return dto.ProviderInfo(
            providerId=self.provider_info_conv.to_ice(bo.provider_id),
            providerInterface=bo.provider_interface,
            providedSkills=self.skillDescriptionMapConv.to_ice(bo.provided_skills),
        )
