import dataclasses as dc

from armarx_core.time.date_time import DateTimeIceConverter

from armarx_skills.manager import dto
from armarx_skills.manager.skill_id import SkillID, SkillIdConv

from armarx_memory.ice_conv.ice_converter import IceConverter


@dc.dataclass
class SkillExecutionID:
    skill_id: SkillID
    executor_name: str
    execution_started_time: int
    uuid: str

    def __hash__(self):
        return hash(self.uuid)


class SkillExecutionIDConv(IceConverter):

    def __init__(self):
        super().__init__()
        self.skill_id_conv = SkillIdConv()
        self.date_time_conv = DateTimeIceConverter()

    @classmethod
    def _import_dto(cls):
        return dto.SkillExecutionID

    def _from_ice(self, dt: dto.SkillExecutionID) -> SkillExecutionID:
        return SkillExecutionID(
            skill_id=self.skill_id_conv.from_ice(dt.skillId),
            executor_name=dt.executorName,
            execution_started_time=self.date_time_conv.from_ice(dt.executionStartedTime),
            uuid=dt.uuid,
        )

    def _to_ice(self, bo: SkillExecutionID) -> dto.SkillExecutionID:
        return dto.SkillExecutionID(
            skillId=self.skill_id_conv.to_ice(bo.skill_id),
            executorName=bo.executor_name,
            executionStartedTime=self.date_time_conv.to_ice(bo.execution_started_time),
            uuid=bo.uuid,
        )
