import dataclasses as dc

from armarx_skills.manager import dto

from armarx_memory.ice_conv.ice_converter import IceConverter


@dc.dataclass
class ProviderID:
    provider_name: str


@dc.dataclass
class SkillID:
    provider_id: ProviderID
    skill_name: str

    def __hash__(self):
        return hash((self.provider_id.provider_name, self.skill_name))


class ProviderIDConv(IceConverter):

    @classmethod
    def _import_dto(cls):
        return dto.ProviderID

    def _from_ice(self, dt: dto.ProviderID) -> ProviderID:
        return ProviderID(provider_name=dt.providerName)

    def _to_ice(self, bo: ProviderID) -> dto.ProviderID:
        return dto.ProviderID(providerName=bo.provider_name)


class SkillIdConv(IceConverter):

    def __init__(self):
        super().__init__()
        self.provider_id_conv = ProviderIDConv()

    @classmethod
    def _import_dto(cls):
        return dto.SkillID

    def _from_ice(self, dt: dto.SkillID) -> SkillID:
        return SkillID(
            provider_id=self.provider_id_conv.from_ice(dt.providerId),
            skill_name=dt.skillName,
        )

    def _to_ice(self, bo: SkillID) -> dto.SkillID:
        return dto.SkillID(
            providerId=self.provider_id_conv.to_ice(bo.provider_id),
            skillName=bo.skill_name,
        )
