import dataclasses as dc
import typing as ty

from armarx_memory.ice_conv.ice_converter import IceConverter
from armarx_memory.aron.conversion import pythonic_from_to_aron_ice as aron_conv
from armarx_skills.core.execution_status import ExecutionStatus, ExecutionStatusConv
from armarx_skills.callback import dti as callback_dti
from armarx_skills.manager import dto
from armarx_skills.manager.skill_execution_id import SkillExecutionID, SkillExecutionIDConv


@dc.dataclass
class SkillStatusUpdate:
    execution_id: SkillExecutionID
    parameters: ty.Dict[str, ty.Any]
    callback_interface: callback_dti.SkillProviderCallbackInterfacePrx
    status: ExecutionStatus
    result: ty.Dict[str, ty.Any]


class SkillStatusUpdateConv(IceConverter):

    def __init__(self):
        super().__init__()
        self.execution_id_conv = SkillExecutionIDConv()
        self.status_conv = ExecutionStatusConv()

    @classmethod
    def _import_dto(cls):
        return dto.SkillStatusUpdate

    def _from_ice(self, dt: dto.SkillStatusUpdate) -> SkillStatusUpdate:
        return SkillStatusUpdate(
            execution_id=self.execution_id_conv.from_ice(dt.executionId),
            parameters=aron_conv.pythonic_from_aron_ice(dt.parameters),
            callback_interface=dt.callbackInterface,
            status=self.status_conv.from_ice(dt.status),
            result=aron_conv.pythonic_from_aron_ice(dt.result),
        )

    def _to_ice(self, bo: SkillStatusUpdate) -> dto.SkillStatusUpdate:
        return dto.SkillStatusUpdate(
            executionId=self.execution_id_conv.to_ice(bo.execution_id),
            parameters=aron_conv.pythonic_to_aron_ice(bo.parameters),
            callbackInterface=bo.callback_interface,
            status=self.status_conv.to_ice(bo.status),
            result=aron_conv.pythonic_to_aron_ice(bo.result),
        )

SkillStatusUpdateMap = ty.Dict[SkillExecutionID, SkillStatusUpdate]
